# DiscordUp
Update Discord via the terminal on Debian powered systems.

# Installation
```
pip install discordup
```

# Usage
It is very easy to use, just type ``discordup`` in your terminal.

# Important
This only works on debian powered systems at the moment.

# To DO
   - Add support for other distros